Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Camera ¶
type Camera struct {
Longitude string `xml:"longitude"`
Latitude string `xml:"latitude"`
Altitude string `xml:"altitude"`
Heading string `xml:"heading"`
Tilt string `xml:"tilt"`
Rll string `xml:"roll"`
AltitudeMode string `xml:"altitudeMode"`
}
Camera struct
type Document ¶
type Document struct {
Name string `xml:"name"`
StyleM StyleMap `xml:"StyleMap"`
Style []Style `xml:"Style"`
F []Folder `xml:"Folder"`
Lookat LookAt `xml:"LookAt"`
NetLink NetworkLink `xml:"NetworkLink"`
}
Document struct
type Folder ¶
type Folder struct {
Name string `xml:"name"`
Visibility string `xml:"description"`
Open int `xml:"open"`
F []Folder `xml:"Folder"`
Lookat LookAt `xml:"LookAt"`
Placemarks []PlaceMark `xml:"Placemark"`
PhotoOverlayList []PhotoOverlay `xml:"PhotoOverlay"`
}
Folder struct
type HotSpot ¶
type HotSpot struct {
X string `xml:"x,attr"`
Y string `xml:"y,attr"`
Xunits string `xml:"xunits,attr"`
Yunits string `xml:"yunits,attr"`
}
HotSpot struct
type IconStyle ¶
type IconStyle struct {
Scale string `xml:"scale"`
Ico Icon `xml:"Icon"`
HS HotSpot `xml:"hotSpot"`
}
IconStyle struct customizes the pinpoints
type ItemIcon ¶
ItemIcon struct
type KML ¶
type KML struct {
Doc Document `xml:"Document"`
Placemarks []PlaceMark `xml:"Placemark"`
F Folder `xml:"Folder"`
NetLink NetworkLink `xml:"NetworkLink"`
}
KML struct
type LineString ¶
type LineString struct {
Tssellate string `xml:"tessellate"`
AltitudeMode string `xml:"altitudeMode"`
Coordinates string `xml:"coordinates"`
}
LineString struct identifies at least two points to connect
type LineStyle ¶
LineStyle struct styles the strokes that join two or more geographical points
type ListStyle ¶
type ListStyle struct {
ListItemType string `xml:"listItemType"`
ItemIco ItemIcon `xml:"ItemIcon"`
BgColor string `xml:"bgColor"`
MaxSnippetLines string `xml:"maxSnippetLines"`
}
ListStyle struct
type LookAt ¶
type LookAt struct {
Longitude string `xml:"longitude"`
Latitude string `xml:"latitude"`
Altitude string `xml:"altitude"`
Range string `xml:"range"`
Tilt string `xml:"tilt"`
Heading string `xml:"heading"`
AltitudeMode string `xml:"altitudeMode"`
}
LookAt struct
type NetworkLink ¶
type NetworkLink struct {
Name string `xml:"name"`
Visibility int `xml:"visibility"`
Open int `xml:"open"`
Lookat LookAt `xml:"LookAt"`
FlyToView string `xml:"flyToView"`
URLInfo URL `xml:"Url"`
}
NetworkLink struct
type Pair ¶
Pair struct
type PhotoOverlay ¶
type PhotoOverlay struct {
Name string `xml:"name"`
Cam Camera `xml:"Camera"`
Style Style `xml:"Style"`
Ico Icon `xml:"Icon"`
Rotation string `xml:"rotation"`
VVolume ViewVolume `xml:"ViewVolume"`
P Point `xml:"Point"`
}
PhotoOverlay struct
type PlaceMark ¶
type PlaceMark struct {
Name string `xml:"name"`
Description string `xml:"description"`
P Point `xml:"Point"`
StyleURL string `xml:"styleUrl"`
LineS LineString `xml:"LineString"`
}
PlaceMark struct pinpoints a location through reference to the Earth’s surface
type Point ¶
type Point struct {
AltitudeMode string `xml:"altitudeMode"`
Coordinates string `xml:"coordinates"`
}
Point struct contains geographical information
type Style ¶
type Style struct {
IconS IconStyle `xml:"IconStyle"`
LineS LineStyle `xml:"LineStyle"`
ListS ListStyle `xml:"ListStyle"`
}
Style struct
Source Files
¶
- kmlstruct.go
Click to show internal directories.
Click to hide internal directories.